#include <iostream>

using namespace std;
using ld  = long double;


struct Point {
    ld x, y;

    Point() {}

    Point(ld x, ld y) : x(x), y(y) {}
};

struct Vector {
    ld x, y;

    Vector() {}

    Vector(ld x, ld y) : x(x), y(y) {}

    Vector(Point &A, Point &B) {
        x = B.x - A.x;
        y = B.y - A.y;
    }

    ld dotProduct(Vector &v) {
        return x * v.x + y * v.y;
    }

    ld crossProduct(Vector &v) {
        return x * v.y - y * v.x;
    }

    Vector rot90() {
        return Vector(-y, x);
    }

    Vector neg() {
        return Vector(-x, -y);
    }
};

struct Line {
    ld a, b, c;

    Line(Point P, Point Q) {
        Vector norm = Vector(P, Q).rot90();
        a = norm.x;
        b = norm.y;
        c = -a * P.x - b * P.y;
    }

    Point intersect(Line l) {
        auto &[a1, b1, c1] = *this;
        auto &[a2, b2, c2] = l;
        ld y = (c2 * a1 - c1 * a2) / (b1 * a2 - a1 * b2);
        ld x = (c2 * b1 - c1 * b2) / (a1 * b2 - a2 * b1);
        return Point(x, y);
    }

    bool intersects(Line l) {
        Vector n1 = Vector(a, b);
        Vector n2 = Vector(l.a, l.b);
        return n1.crossProduct(n2) != 0;
    }
};

bool pointInSegment(Point P, Point Q, Point H) {
    Vector HP(H, P);
    Vector HQ(H, Q);
    return HP.dotProduct(HQ) <= 0;
}

bool pointInRay(Point H, Point A, Point B) {
    Vector AH(A, H);
    Vector AB(A, B);
    return AH.dotProduct(AB) >= 0;
}

bool intersects(Point P, Point Q, Point A, Point B) {
    Vector PQ(P, Q);
    Vector AB(A, B);
    if (PQ.crossProduct(AB) == 0 )  {
        Vector AP(A, P);
        return AP.crossProduct(AB) >= 0;
    }
    Line l1(A, B);
    Line l2(P, Q);
    if (!l1.intersects(l2)) {
        return false;
    }
    Point H = l1.intersect(l2);
    return pointInSegment(P, Q, H) && pointInRay(H, A, B);
}

Point addToP(Point P, Vector v) {
    return Point(P.x + v.x, P.y + v.y);
}

bool solve() {
    Point A, B, C, D;
    Vector v;
    cin >> A.x >> A.y >> B.x >> B.y >> C.x >> C.y >> D.x >> D.y;
    cin >> v.x >> v.y;
    Vector AB(A, B);
    Vector CD(C, D);
    if (AB.crossProduct(CD) == 0) {
        Vector BC(B, C);
        return v.crossProduct(BC) == 0 && v.dotProduct(BC) >= 0;
    }

    Point A2 = addToP(A, v);
    Point B2 = addToP(B, v);
    bool r1 = intersects(C, D, A, A2);
    bool r2 = intersects(C, D, B, B2);
    if (r1 || r2) {
        return true;
    }
    Point C2 = addToP(C, v.neg());
    Point D2 = addToP(D, v.neg());
    bool r3 = intersects(A, B, C, C2);
    bool r4 = intersects(A, B, D, D2);
    if (r3 || r4) {
        return true;
    }
    return false;
}

int main() {
#ifdef LOCAL
    freopen("B.in", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    int n;
    cin >> n;
    for (int i = 0; i < n; ++i) {
        if (solve()) {
            cout << "Yes\n";
        } else {
            cout << "No\n";
        }
    }

    return 0;
}