#include <iostream>
#include <algorithm>
#include <vector>
#include <string>

using namespace std;

typedef long long ll;

struct Point {
	ll x, y;
	Point(ll x = 0, ll y = 0) {
		this->x = x;
		this->y = y;
	}
};

struct Vector {
	ll x, y;
	Vector() {}
	Vector(ll x, ll y) {
		this->x = x;
		this->y = y;
	}
	Vector(Point p1, Point p2) {
		x = p2.x - p1.x;
		y = p2.y - p1.y;
	}
};

ll cross_prod(Vector v1, Vector v2) {
	return v1.x * v2.y - v2.x * v1.y;
}

ll dot_prod(Vector v1, Vector v2) {
	return v1.x * v2.x + v1.y * v2.y;
}

int sign(ll x) {
	if (x > 0)
		return 1;
	if (x < 0)
		return -1;
	return 0;
}

bool point_on(Point a, Point b, Point p, Vector v) {
	if (cross_prod(Vector(a, b), Vector(a, p)) == 0) {
		if (cross_prod(Vector(a, b), v) != 0)
			return false;
		return dot_prod(Vector(a, p), v) > 0;
	}

	if (cross_prod(Vector(a, b), v) == 0)
		return false;
	if (sign(cross_prod(Vector(a, b), Vector(a, p))) != sign(cross_prod(Vector(a, b), v)))
		return false;

	Vector ap(a, p), bp(b, p);
	return sign(cross_prod(v, ap)) * sign(cross_prod(v, bp)) <= 0;
}

bool inter(Point a, Point b, Point c, Point d, Vector v) {
	if (point_on(a, b, c, v))
		return true;
	if (point_on(a, b, d, v))
		return true;
	if (point_on(c, d, a, Vector(-v.x, -v.y)))
		return true;
	if (point_on(c, d, b, Vector(-v.x, -v.y)))
		return true;
	return false;
}

Point a, b, c, d;
Vector v;
int n;

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	cin >> n;
	for (int i = 0; i < n; i++) {
		cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y;
		cin >> v.x >> v.y;
		if (inter(a, b, c, d, v))
			cout << "Yes" << endl;
		else
			cout << "No" << endl;
	}
}