#include <bits/stdc++.h>

using namespace std;

const double EPS = 1e-6;
const double INF = 1e9;

bool isLess(double a, double b)
{
    return b > a + EPS;
}

bool isMore(double a, double b)
{
    return a > b + EPS;
}

bool isEqual(double a, double b)
{
    return (!isLess(a, b) && !isMore(a, b));
}

struct Point
{
    double x, y;
    Point(double x, double y): x(x), y(y) {};
    Point(): x(0), y(0) {};
};

struct Line
{
    double A, B, C;
    Line(): A(0), B(0), C(0) {};
    Line(double A, double B, double C): A(A), B(B), C(C) {};
};

Point LineIntersect(Line a, Line b)
{
    if (isEqual(a.A * b.B - a.B * b.A, 0) || isEqual(a.B * b.A - a.A * b.B, 0))
    {
        return Point(INF, INF);
    }
    return Point((b.C * a.B - a.C * b.B ) / (a.A * b.B - a.B * b.A), (b.C * a.A - a.C * b.A) / (a.B * b.A - a.A * b.B));
}

Line ParallelLine(Point a, Line l)
{
    return Line(l.A, l.B, -(l.A * a.x + l.B * a.y));
}

long long vecMult(Point a, Point b)
{
    return {a.x * b.y - a.y * b.x};
}

Line lineGet(Point a, Point b)
{
    Line ans;
    ans.A = a.y - b.y;
    ans.B = -(a.x - b.x);
    ans.C = -(ans.A * a.x + ans.B * a.y);
    return ans;
}

double getDist(Point a, Line l)
{
    return (a.x * l.A + a.y * l.B + l.C);
}

bool pointOnSegment(Point a1, Point p1, Point p2)
{
    Line l = lineGet(p1, p2);
    if (!isEqual(l.A * a1.x + l.B * a1.y + l.C, 0))
    {
        return false;
    }
    if ((!isLess(a1.x, min(p1.x, p2.x)) && !isMore(a1.x, max(p1.x, p2.x))) || (!isLess(a1.y, min(p1.y, p2.y)) && !isMore(a1.y, max(p1.y, p2.y))))
    {
        return true;
    }
    return false;
}

bool f(Point A, Point B, Point v)
{
    B.x -= A.x;
    B.y -= A.y;
    if ((!isLess(v.y, 0) && !isLess(B.y, 0)) || (!isMore(v.y, 0) && !isMore(B.y, 0)))
    {
        return true;
    }
    return false;
}

int main()
{
    int n;
    cin >> n;
    while (n--)
    {
        Point a1, a2, b1, b2, v;
        cin >> a1.x >> a1.y >> a2.x >> a2.y >> b1.x >> b1.y >> b2.x >> b2.y >> v.x >> v.y;
        Line a = lineGet(a1, a2);
        Line b = lineGet(b1, b2);
        Line vec = lineGet(Point(0, 0), v);

        Line l1 = ParallelLine(b1, vec);
        Line l2 = ParallelLine(b2, vec);
        Point p1 = LineIntersect(a, l1);
        Point p2 = LineIntersect(a, l2);
        if ((!isLess(getDist(p1, b), 0) && !isLess(getDist(p2, b), 0)) || ((!isMore(getDist(p1, b), 0) && !isMore(getDist(p2, b), 0))))
        {
            if (f(p1, b1, v))
            {
                if (pointOnSegment(a1, p1, p2) || pointOnSegment(a2, p1, p2))
                {
                    cout << "Yes\n";
                }
                else
                {
                    cout << "No\n";
                }
            }
            else
            {
                cout << "No\n";
            }
        }
        else
        {
            if (f(p1, b1, v))
            {
                if (!isLess(getDist(p1, b), 0))
                {
                    if (pointOnSegment(a1, p1, p2) && !isLess(getDist(a1, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else if (pointOnSegment(a2, p1, p2) && !isLess(getDist(a2, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else
                    {
                        cout << "No\n";
                    }
                }
                else
                {
                    if (pointOnSegment(a1, p1, p2) && !isMore(getDist(a1, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else if (pointOnSegment(a2, p1, p2) && !isMore(getDist(a2, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else
                    {
                        cout << "No\n";
                    }
                }
            }
            else
            {
                if (!isLess(getDist(p2, b), 0))
                {
                    if (pointOnSegment(a1, p1, p2) && !isLess(getDist(a1, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else if (pointOnSegment(a2, p1, p2) && !isLess(getDist(a2, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else
                    {
                        cout << "No\n";
                    }
                }
                else
                {
                    if (pointOnSegment(a1, p1, p2) && !isMore(getDist(a1, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else if (pointOnSegment(a2, p1, p2) && !isMore(getDist(a2, b), 0))
                    {
                        cout << "Yes\n";
                    }
                    else
                    {
                       cout << "No\n";
                    }
                }
            }
        }
    }
}
