#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

typedef long long ll;
typedef long double ld;

const ld EPS = 1e-5;

struct Point {
	ld x, y;
	Point() : x(0), y(0) {}
	Point(ld a, ld b) : x(a), y(b) {}
};

istream& operator >> (istream& is, Point& p) {
	is >> p.x >> p.y;
	return is;
}

struct Vect {
	ld x, y;
	Vect(Point a, Point b) : x(b.x - a.x), y(b.y - a.y) {}
	Vect(ld a, ld b) : x(a), y(b) {}
	Vect() : x(0), y(0) {}
};

Point operator + (Point a, Vect b) {
	return Point(a.x + b.x, a.y + b.y);
}

ld range(Point a, Point b) {
	return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

struct Line {
	ld A, B, C;
	Line(Point a, Point b) : A(a.y - b.y), B(b.x - a.x), C(-A * a.x - B * a.y) {}

	friend bool operator == (Line a, Line b) {
		return b.A * a.B * a.C == a.A * b.B * a.C && a.A * b.B * a.C == a.A * a.B * b.C;
	}
};

bool In(Point a, Point b, Point p) {
	return abs(range(a, b) - range(a, p) - range(p, b)) < EPS;
}

bool eq(ld a, ld b) {
	return (a >= 0 && b >= 0) || (a <= 0 && b <= 0);
}

bool Check(Point fgh, Line a, Line b, Point f, Point s, Vect c) {
	if (a == b && eq(Vect(fgh, f).x, c.x) && eq(Vect(fgh, f).y, c.y)) return true;
	if (a.A * b.B - b.A * a.B == 0) return false;
	Point ans;
	ans.x = -(a.C * b.B - b.C * a.B) / (a.A * b.B - b.A * a.B);
	ans.y = -(a.A * b.C - b.A * a.C) / (a.A * b.B - b.A * a.B);
	ld rofl1 = Vect(fgh, ans).x, rofl2 = Vect(fgh, ans).y;
	if (!eq(rofl1, c.x) || !eq(rofl2, c.y)) return false;
	return In(f, s, ans);
}

int main() {

	//fstream cin("input.txt");
	//ofstream cout("output.txt");

	int t; cin >> t;
	while (t--) {
		Point a, b, c, d; cin >> a >> b >> c >> d;
		ld x, y; cin >> x >> y;
		Vect cur = Vect(x, y);
		Line fir = Line(a, b), sec = Line(c, d);

		if (Check(a, Line(a, a + cur), sec, c, d, cur) || Check(b, Line(b, b + cur), sec, c, d, cur) || Check(c, Line(c, c + cur), fir, a, b, Vect(-cur.x, -cur.y)) || Check(d, Line(d, d + cur), fir, a, b, Vect(-cur.x, -cur.y)))
			cout << "Yes" << endl;
		else
			cout << "No" << endl;
	}

}