#include <bits/stdc++.h>
using namespace std;
#define double long double

const double eps = 1e-6;

struct pt {
    double x, y;
    pt (double x, double y): x(x), y(y) {}
    pt () {}
    bool operator == (pt p) {
        return x == p.x && y == p.y;
    }
};

double operator % (pt a, pt b) {
    return a.x * b.y - a.y * b.x;
}

double operator * (pt a, pt b) {
    return a.x * b.x + a.y * b.y;
}

pt operator - (pt a, pt b) {
    return {a.x - b.x, a.y - b.y};
}

pt operator + (pt a, pt b) {
    return {a.x + b.x, a.y + b.y};
}

bool in_ray(pt a, pt la, pt p) {
    return abs((la - a) % (p - a)) < eps && (la - a) * (p - a) > 0;
}

int sig(double x) {
    return x < 0 ? -1 : 1;
}

bool one_side(pt la, pt lb, pt a, pt b) {
    return sig((lb - la) % (a - la)) == sig((lb - la) % (b - la));
}

bool in_rays(pt a, pt la, pt b, pt lb, pt p) {
    if (in_ray(a, la, p) || in_ray(b, lb, p))
            return 1;
    if (!one_side(a, b, p, la))
            return 0;
    return sig((la - a) % (p - a)) != sig((lb - b) % (p - b));
}

const pt gg = { 113, 228 };

void get_line(pt p1, pt p2, double &a, double &b, double &c) {
    if (p1.x == p2.x) {
        a = 1;
        b = 0;
        c = -p1.x;
        return;
    }
    a = (p1.y - p2.y) / (p1.x - p2.x);
    b = -1;
    c = (p1.y * p2.x - p1.x * p2.y) / (p2.x - p1.x);
}

pt line_int(pt a, pt la, pt b, pt lb) {
    double a1, a2, b1, b2, c1, c2;
    get_line(a, la, a1, b1, c1);
    get_line(b, lb, a2, b2, c2);
    double dl = a1 * b2 - a2 * b1;
    if (abs(dl) < eps) {
        return gg;
    }
    return { (b1 * c2 - c1 * b2) / dl, (a2 * c1 - a1 * c2) / dl };
}

bool ray_ray(pt a, pt la, pt b, pt lb) {
    if (line_int(a, la, b, lb) == gg)
        return 0;
    pt in = line_int(a, la, b, lb);
    return in_ray(a, la, in) && in_ray(b, lb, in);
}

bool ray_seg(pt a, pt la, pt p1, pt p2) {
    return ray_ray(a, la, p1, p2) && ray_ray(a, la, p2, p1);
}

bool solve(pt a, pt la, pt b, pt lb, pt p1, pt p2) {
    if (in_rays(a, la, b, lb, p1) || in_rays(a, la, b, lb, p2))
        return 1;
    return ray_seg(a, la, p1, p2) || ray_seg(b, lb, p1, p2);
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    int n;
    cin >> n;

    while (n--) {
        pt a, la, b, lb, p1, p2;
        {
            pt A, B, C, D, V;
            cin >> A.x >> A.y >> B.x >> B.y >> C.x >> C.y >> D.x >> D.y >> V.x >> V.y;
            a = A;
            la = A + V;
            b = B;
            lb = B + V;
            p1 = C;
            p2 = D;
            if (solve(a, la, b, lb, p1, p2)) {
                cout << "Yes\n";
            }
            else {
                cout << "No\n";
            }
        }
    }
}