#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <algorithm>
#include <vector>
#include <cmath>
#include <math.h>

#define endl '\n'

using namespace std;

typedef long long ll;
typedef long double ld;

const ld eps = 1e-7;

bool Equal(ld a, ld b) {
	return fabs(a - b) < eps;
}
bool LessOrEqual(ld a, ld b) {
	return a < b || Equal(a, b);
}
bool MoreOrEqual(ld a, ld b) {
	return a > b || Equal(a, b);
}

bool Less(ld a, ld b) {
	return (!Equal(a, b) && a < b);
}
bool More(ld a, ld b) {
	return (!Equal(a, b) && a > b);
}

struct point {
	ll x, y;
	point() {

	}
	void scan() {
		cin >> x >> y;
	}
	point(ll _x, ll _y) {
		x = _x;
		y = _y;
	}
	point operator-() const {
		return point(-x, -y);
	}
	point operator+(const point& p) const {
		return point(x + p.x, y + p.y);
	}
	point operator-(const point& p)const {
		return point(x - p.x, y - p.y);
	}
	point operator*(const ll k) const {
		return point(x * k, y * k);
	}
	ll operator*(const point& p) const {
		return (x * p.y - y * p.x);
	}
	ll operator%(const point& p) const {
		return (x * p.x + y * p.y);
	}
	bool is_on_line(const point& A, const point& B) const {
		return Equal((A - *this) * (B - *this), 0);
	}

	bool is_on_segment(const point& A, const point& B) const {
		if (is_on_line(A, B) && LessOrEqual((A - *this) % (B - *this), 0))
			return true;
		else
			return false;
	}

};

pair<int, point> lines_cross(const point& A, const point& B, const point& C, const point& D) {
	ld s1 = (C - A) * (D - A);
	ld s2 = (D - B) * (C - B);
	ld s = s1 + s2;
	point V = B - A;
	//V = V / s;
	V = V * s1;
	point O = A + V;
	if (Equal(s, 0)) {
		if (!A.is_on_line(C, D))
			return { 0, point() };
		return { 2, point() };
	}
	return { 1, O };
}

bool is_segments(const point& A, const point& B, const point& C, const point& D) {
	if (A.is_on_segment(C, D) || B.is_on_segment(C, D) || C.is_on_segment(A, B) || D.is_on_segment(A, B))
		return true;
	if (A.is_on_line(C, D) && B.is_on_line(C, D))
		return false;
	if (C.is_on_line(A, B) && D.is_on_line(A, B))
		return false;
	if (lines_cross(A, B, C, D).first == 1) {
		point O = lines_cross(A, B, C, D).second;
		if (O.is_on_segment(A, B) && O.is_on_segment(C, D)) {
			return true;
		}
	}
	if (lines_cross(A, B, C, D).first == 2) {
		if (A.is_on_segment(C, D) || B.is_on_segment(C, D) || C.is_on_segment(A, B) || D.is_on_segment(A, B))
			return true;
	}
	return false;
}

int get(ll vec) {
	if (vec == 0)
		return 0;
	if (vec < 0)
		return 1;
	if (vec > 0)
		return 2;
}

bool segment_cross(const point& A, const point& B, const point& C, const point& D) {
	if (A.is_on_segment(C, D) || B.is_on_segment(C, D) || C.is_on_segment(A, B) || D.is_on_segment(A, B))
		return true;
	if (A.is_on_line(C, D) && B.is_on_line(C, D))
		return false;
	if (C.is_on_line(A, B) && D.is_on_line(A, B))
		return false;
	if (get((D - A) * (B - A)) != get((B - A) * (C - A)))
		return false;
	if (get((B - D) * (C - D)) != get((C - D) * (A - D)))
		return false;
	if (get((C - B) * (A - B)) != get((A - B) * (D - B)))
		return false;
	if (get((A - C) * (D - C)) != get((D - C) * (B - C)))
		return false;
	return true;
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
#ifdef _DEBUG 
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	int n;
	cin >> n;
	point a1, a2, b1, b2, v;
	for (int i = 0; i < n; i++) {
		a1.scan();
		a2.scan();
		b1.scan();
		b2.scan();
		v.scan();
		while (fabs(v.x) < 1e7 && !Equal(v.x, 0))
			v = v * 10;
		while (fabs(v.y) < 1e7 && !Equal(v.y, 0))
			v = v * 10;
		if (segment_cross(a1, a1 + v, b1, b2)) {
			cout << "Yes" << endl;
			continue;
		}
		if (segment_cross(a2, a2 + v, b1, b2)) {
			cout << "Yes" << endl;
			continue;
		}
		if (segment_cross(b1, b1 - v, a1, a2)) {
			cout << "Yes" << endl;
			continue;
		}
		if (segment_cross(b2, b2 - v, a1, a2)) {
			cout << "Yes" << endl;
			continue;
		}
		cout << "No" << endl;
	}
}